
********************************
*Quantile Regression
*BSE, May 2023

*this is a slighly modified version of Cameron and Trivedi's do file. 
********************************


* oenb_4endog_quantile.do  based on mus14p1bin.do  September 2010 for Stata version 10.1

log using oenb_4endog_quantile.txt, text replace

********** OVERVIEW OF oenb_4endog_quantile.do **********

* STATA Program 
* For A. Colin Cameron and Pravin Trivedi "Lectures in Microeconometrics"
* Binary models

* To run you need files
*   mus03data.dta 
* in your directory

********** SETUP **********

set more off
version 10
set mem 10m
set scheme s1mono  /* Graphics scheme */
 
**** QUANTILE REGRESSION  INCREASE NUMBER OF BOOTSTRAP REPS- HERE 100

* Read in log of medical expenditures data and summarize
use mus03data.dta, clear
sum totexp ltotexp
bysort suppins: sum totexp ltotexp
drop if ltotexp == . 
summarize ltotexp suppins totchr age female white, separator(0)

* Compare two distributions
bysort suppins: sum ltotexp totexp
graph twoway (kdensity ltotexp if suppins == 1) (kdensity ltotexp if suppins == 0, lstyle(p2)), ///
  legend( label(1 "suppins==1") label(2 "suppins==0"))
graph export densitycomparison.pdf, replace

qplot ltotexp, over(suppins) recast(line) scale(1.2) legend( label(1 "suppins==0") label(2 "suppins==1"))
graph export cdfcomparison.wmf, replace

centile ltotexp if suppins==1, centile(10 50 90)
centile ltotexp if suppins==0, centile(10 50 90)

* Quantile regession on constant and an indicator
qreg ltotexp if suppins==1, q(.1)
matrix b1 = e(b)
qreg ltotexp if suppins==0, q(.1)
matrix b0 = e(b)
matrix diff = b1 - b0
matrix list diff
qreg ltotexp suppins, q(.1)
sqreg ltotexp suppins, q(.1 .5 .9) reps(100) nodots

* Quantile regression on saturated model
sum totchr
qplot ltotexp, over(totchr) recast(line) scale(1.1)
graph export cdfovertotchr.wmf, replace
bysort totchr: centile ltotexp, centile(10) 
quietly tabulate totchr, generate(dtotchr)
drop dtotchr1
qreg ltotexp dtotchr*, q(.1) nolog
bysort totchr: centile ltotexp, centile(10 50 90) 

* Quantile regression with linearity imposed
qreg ltotexp totchr, q(.1)
sqreg ltotexp totchr, q(.1 .5 .9) reps(100) nodots

* Save the results and plot lines
qreg ltotexp totchr, q(.75)
predict q1
qreg ltotexp totchr, q(.5)
predict q5
qreg ltotexp totchr, q(.25)
predict q9
quietly summarize ltotexp, d
scalar median = r(p50)
generate medltotexp = median
sort totchr
graph twoway (scatter q1 totchr, c(l) msize(vtiny) clstyle(p2)) ///
 (scatter q5 totchr, c(l) msize(vtiny) clstyle(p3)) ///
 (scatter q9 totchr, c(l) msize(vtiny) clstyle(p4)) /// 
 (scatter medltotexp totchr, c(l) msize(vtiny) clstyle(p1)), ///
 legend( label(1 ".75 quantile") label(2 ".50 quantile") ///
 label(3 ".25 quantile") label(4 "Median of y"))
graph export quantileregression.wmf, replace


* Now two regressors
sqreg ltotexp suppins totchr, q(.1 .5 .9) reps(100) nodots
sqreg ltotexp suppins, q(.1 .5 .9) reps(100) nodots
sqreg ltotexp totchr, q(.1 .5 .9) reps(100) nodots

sqreg ltotexp suppins totchr age female white, q(.1 .5 .9) reps(100) nodots

regress ltotexp totchr age female white
predict ltotexpres, residuals
regress suppins totchr age female white
predict suppinsres, residuals
sqreg ltotexpres suppinsres, q(.1 .5 .9) reps(100) nodots




*PLOTTING COEFFICINTS OVER QUANTILES
 ssc install grqreg

 sqreg ltotexp suppins totchr age female white, q(.1  .5 .9) reps(100) nodots

quietly grqreg ltotexp totchr age female white, quantile(.5) reps(400)

qrgqreg, cons ci ols olsci scale(1.1)


 bsqreg ltotexp suppins totchr age  , reps(100)
 grqreg, cons ci ols olsci title(constant suppins totchr age)




********** CLOSE OUTPUT
* log close
* clear
* exit
